﻿using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Web.UI;
using PdfSharp;
using PdfSharp.Drawing;
using PdfSharp.Pdf;
using ThinkGeo.MapSuite.Core;

namespace CSSamples.Samples.Extending_MapSuite {
    public partial class UsePdfExtension : System.Web.UI.Page {
        protected void Page_Load(object sender, EventArgs e) {
            if (!Page.IsPostBack) {
                Map1.MapUnit = GeographyUnit.DecimalDegree;
                Map1.CurrentExtent = new RectangleShape(-51, 121, 149, -13);
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));

                InMemoryFeatureLayer inMemoryLayer = new InMemoryFeatureLayer();
                inMemoryLayer.InternalFeatures.Add("Line", new Feature(BaseShape.CreateShapeFromWellKnownData("LINESTRING(60 60, 70 70,75 60, 80 70, 85 60,95 80)")));
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = new LineStyle(new GeoPen(GeoColor.StandardColors.Black, 10));
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle.OuterPen.StartCap = DrawingLineCap.Round;
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle.OuterPen.EndCap = DrawingLineCap.ArrowAnchor;
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                Map1.StaticOverlay.Layers.Add("WorldLayer", inMemoryLayer);
            }
        }

        protected void btnToPdf_Click(object sender, EventArgs e) {
            Bitmap bitmap = new Bitmap((int)Map1.Width.Value, (int)Map1.Height.Value);
            MapEngine engine = new MapEngine();
            engine.CurrentExtent = Map1.CurrentExtent;
            engine.ShowLogo = false;
            foreach (Layer layer in Map1.StaticOverlay.Layers) {
                engine.StaticLayers.Add(layer);
            }
            engine.OpenAllLayers();
            engine.DrawStaticLayers(bitmap, Map1.MapUnit);
            engine.CloseAllLayers();

            PdfDocument document = new PdfDocument();
            PdfPage page = document.AddPage();
            if (rdlOptions.SelectedItem.Text == "Landscape") {
                page.Orientation = PageOrientation.Landscape;
            }

            XImage image = XImage.FromGdiPlusImage(bitmap);
            XGraphics xGraphics = XGraphics.FromPdfPage(page);
            //You could draw image the way you like here
            xGraphics.DrawImage(image, 0, 0);

            string filename = Directory.GetCurrentDirectory() + "\\MapSuite PDF Map.pdf";
            document.Save(filename);
            OpenPdfFile(filename);
        }

        private static void OpenPdfFile(string filename) {
            try {
                Process.Start(filename);
            }
            catch (Win32Exception ex) {
                if (ex.Message == "No application is associated with the specified file for this operation") {
                    //string message = "You can't open Pdf file, the reason maybe you don't install Adobe Reader\r\n\r\n" + ex.ToString();
                    //MessageBox.Show(message, "Open Pdf file failed", MessageBoxButtons.OK, MessageBoxIcon.Error, MessageBoxDefaultButton.Button1, (MessageBoxOptions)0);
                    ProcessStartInfo psi = new ProcessStartInfo(@"C:\WINDOWS\system32\rundll32.exe");
                    psi.Arguments = @" C:\WINDOWS\system32\shell32.dll, OpenAs_RunDLL " + filename;
                    Process.Start(psi);
                }
            }
        }
    }
}
